@@ -8,7 +8,7 @@ package Devel::MAT::SV;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Carp;
 use Scalar::Util qw( weaken );
@@ -251,6 +251,21 @@ sub backrefs
    return undef;
 }
 
+=head2 rootname
+
+   $rootname = $sv->rootname
+
+If the SV is a well-known root, this method returns its name. Otherwise
+returns C<undef>.
+
+=cut
+
+sub rootname
+{
+   my $self = shift;
+   return $self->{rootname};
+}
+
 # internal
 sub more_magic
 {
@@ -389,7 +404,7 @@ boolean true and false. They are
 
 package Devel::MAT::SV::Immortal;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 use constant immortal => 1;
 sub new {
    my $class = shift;
@@ -402,13 +417,13 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::UNDEF;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 sub desc { "UNDEF" }
 sub type { "UNDEF" }
 
 package Devel::MAT::SV::YES;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 sub desc { "YES" }
 sub type { "SCALAR" }
 
@@ -423,7 +438,7 @@ sub name {}
 
 package Devel::MAT::SV::NO;
 use base qw( Devel::MAT::SV::Immortal );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 sub desc { "NO" }
 sub type { "SCALAR" }
 
@@ -438,7 +453,7 @@ sub name {}
 
 package Devel::MAT::SV::Unknown;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 0xff );
 
 sub desc { "UNKNOWN" }
@@ -447,7 +462,7 @@ sub _outrefs {}
 
 package Devel::MAT::SV::GLOB;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 1 );
 use constant $CONSTANTS;
 
@@ -611,7 +626,7 @@ sub _outrefs
 
 package Devel::MAT::SV::SCALAR;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 2 );
 use constant $CONSTANTS;
 
@@ -772,7 +787,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REF;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 3 );
 use constant $CONSTANTS;
 
@@ -863,7 +878,7 @@ sub _outrefs
 
 package Devel::MAT::SV::ARRAY;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 4 );
 use constant $CONSTANTS;
 
@@ -1004,7 +1019,7 @@ sub _outrefs
 package Devel::MAT::SV::PADLIST;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 use constant type => "PADLIST";
 use constant $CONSTANTS;
 
@@ -1053,7 +1068,7 @@ sub _outrefs
 package Devel::MAT::SV::PADNAMES;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 use constant type => "PADNAMES";
 use constant $CONSTANTS;
 
@@ -1137,7 +1152,7 @@ sub _outrefs
 package Devel::MAT::SV::PAD;
 # Synthetic type
 use base qw( Devel::MAT::SV::ARRAY );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 use constant type => "PAD";
 use constant $CONSTANTS;
 
@@ -1230,7 +1245,7 @@ sub _outrefs
 
 package Devel::MAT::SV::HASH;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 5 );
 use constant $CONSTANTS;
 
@@ -1391,7 +1406,7 @@ sub _outrefs
 
 package Devel::MAT::SV::STASH;
 use base qw( Devel::MAT::SV::HASH );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 6 );
 use constant $CONSTANTS;
 
@@ -1531,7 +1546,7 @@ sub _outrefs
 
 package Devel::MAT::SV::CODE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 7 );
 use constant $CONSTANTS;
 
@@ -2027,7 +2042,7 @@ sub _outrefs
 
 package Devel::MAT::SV::IO;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 8 );
 use constant $CONSTANTS;
 
@@ -2101,7 +2116,7 @@ sub _outrefs
 
 package Devel::MAT::SV::LVALUE;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 9 );
 use constant $CONSTANTS;
 
@@ -2142,7 +2157,7 @@ sub _outrefs
 
 package Devel::MAT::SV::REGEXP;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 10 );
 
 sub load {}
@@ -2153,7 +2168,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::FORMAT;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 11 );
 
 sub load {}
@@ -2164,7 +2179,7 @@ sub _outrefs { () }
 
 package Devel::MAT::SV::INVLIST;
 use base qw( Devel::MAT::SV );
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 __PACKAGE__->register_type( 12 );
 
 sub load {}
